# mbdyn-lexer

## Description
Pygments Lexer Class for MBDyn Inputfiles.


## Installation
Coming soon.

## Usage
Coming soon.

## Support
Coming soon.

## Authors and acknowledgment
Coming soon.

## License
GNU GENERAL PUBLIC LICENSE
Version 3, 29 June 2007

## Project status
Coming soon.
